/*
6_consumpbask.do
Hugh Montag
11/29/2023
From "On the Welfare Costs of Perception Biases", JCMB (forthcoming)

Goal: Make consumption basket graphs for Appendix Figure 1
*/

* Directories
global derdata = "${datapath}\Deriveddata"

* Files to import
local frdata = "${derdata}\cammedata"
local frpanel = "${derdata}\cammepanel"

* Household inflation by income
local hhinfllevel="${derdata}\FRHHinfl_level"
local hhinflvolat="${derdata}\FRHHinfl_volat"

//Cutoff for outliers
local percept_cutoff=20   //Drop all observations where abs(perceptions)>percept_cutoff

*****************************
* Step 1: MAKE CONSUMPTION BASKET GRAPHS
*****************************
//Load up the .dta of inflation rates for households by income quartiles.
//Graph the results and save

clear
use `hhinfllevel'
keep TIME quant BarInflRate
keep if TIME > monthly("2003m1", "YM")

* Graph average inflation rate by household quantile
graph twoway (line BarInflRate TIME if quant == 1, lcolor(red) lpattern(solid) lwidth(medthick)) || ///
(line BarInflRate TIME if quant==5, lcolor(green) lpattern(dash_dot) lwidth(medthick)), ///
legend(label(1 "Low-income Households") label(2 "High-income Households")) ///
title("Inflation Rate by Income")   ///
tlabel(, format(%tmCY)) ///
xtitle("Date") ytitle("Percent") scheme(s1color)

graph export "${graphpath}\appendfig1a.png", replace
graph export "${graphpath}\appendfig1a.pdf", replace
window manage close graph    //Close the open graph window


//Load up the .dta of household inflation volatility by income quartile
clear
use `hhinflvolat'
keep TIME quant CrossCOIVolat
keep if TIME > monthly("2003m1", "YM")

* Graph cross-sectional household inflation rates by household quantile
graph twoway (line CrossCOIVolat TIME if quant == 1, lcolor(red) lpattern(solid) lwidth(medthick)) || ///
(line CrossCOIVolat TIME if quant==5, lcolor(green) lpattern(dash_dot) lwidth(medthick)), ///
legend(label(1 "Low-income Households") label(2 "High-income Households")) ///
title("Within Consumption Basket Inflation Volatility")   ///
tlabel(, format(%tmCY)) ///
xtitle("Date") ytitle("Percent") scheme(s1color)

graph export "${graphpath}\appendfig1b.png", replace
graph export "${graphpath}\appendfig1b.pdf", replace
window manage close graph
