/* 
CleanFranceCPI
Hugh Montag
11/29/2023
From "On the Welfare Costs of Perception Biases", JCMB (forthcoming)


Goal: Import the HICP subindices for France and clean. Only
keep the interesting subindices, and save data in a format later analysis;
*/

clear
set more off
pause on
#delimit ;

* Filepaths;
local hicpsubs="\\filer6\Oplcsrv2\Transmit\Montag_H\JMP\ReplicationPackage\rawdata\hicp_data.csv";
local outpath="\\filer6\Oplcsrv2\Transmit\Montag_H\JMP\ReplicationPackage\derived_data";
/*=======================
  Step 1: All SubCPI
  =======================*/;
* Import CPI subindices;
insheet using `hicpsubs', comma names;
keep if geo=="France";
gen mdate=monthly(time,"YM"); format mdate %tm; 
rename value subind; 
drop unit geo;
describe;
list in 2;

keep if (strlen(coicop)==4 & substr(coicop,1,2)=="CP");  // Only keep 4-digit coiops

* Clean missing values
replace subind="." if subind==":"; 
destring subind, replace; 
gen lnsubind=ln(subind);

* TEST CODE;
drop if lnsubind==.;

sort coicop mdate;
encode coicop, generate(coicopnum);
xtset coicopnum mdate;

tempfile subdata;
save `subdata';

* GEnerate year-on-year changes in coicop indices
gen subindyoy=100*S12.lnsubind;
sort mdate; gen coired=substr(coicop,3,.);
list coicop_label coicop if mdate==monthly("2010m3","YM");
keep mdate coired subindyoy;

* Reshape data to wide, so each variable is an inflation rate for a different CPI sub-component
reshape wide subindyoy, i(mdate) j(coired) string;
rename subindyoy00 hicpinflyoy;
label var hicpinflyoy "Year-on-Year inflation according to HICP";
list in 20; sort mdate;
save France_subcpiM, replace;

* Generate 3-year inflation;
use `subdata', clear;
keep if coicop == "CP00";
gen hicpinfl3yo3y = 100 * S36.lnsubind;
keep mdate hicpinfl3yo3y;
sort mdate;
merge 1:1 mdate using France_subcpiM;
drop _merge;
save "$outpath\France_cpi_subindices, replace;

/*=======================
  Step 2: Food Subcpi
  =======================*/;
* Create a dataset that only contains year-on-year changes for food-related coicops;

* Import CPI subindices;
insheet using `hicpsubs', comma names clear;
keep if geo=="France";
gen mdate=monthly(time,"YM"); format mdate %tm; 
rename value subind; 
drop unit geo time flagandfootnotes;
describe;
* Destring subindex values, dropping missing : values;
destring subind, ignore(":") force replace;

* Set data as panel format, so I can use time-series operators;
encode coicop, generate(coicopnum); 
sort coicopnum mdate;
xtset coicopnum mdate;

* Find year-on-year inflation;
gen lnsubind=ln(subind); drop if lnsubind==.;
gen subindyoy=100*S12.lnsubind;
drop subind lnsubind;

* Label some variables;
label var coicop "COICOP Code";
label var coicop_label "Text Description of COICOP Code";
label var coicopnum "Numeric version of COICOP Code";
label var subindyoy "Year-on-year inflation rate for COICOP category";

* Reshape this dataset wide, so that we can run regressions of perceptions
* on these categories;
drop coicop_label coicopnum; //Drop unnecessary variables for the regression;
sort coicop;

// CREATE FOOD DATASET;
* Only keep food-related subindices;
keep if (substr(coicop,4,1)=="1" & (inlist(strlen(coicop),5,6,7))) | 
(substr(coicop,1,5)=="TOT_X") |
(substr(coicop,1,4)=="FOOD") | (coicop=="CP00") | 
(coicop=="CP021") | (coicop=="CP022") | (coicop=="CP07222");

reshape wide sub*, i(mdate) j(coicop) string;   //Reshape wide;

* Save the results;
save "$outpath\France_foodcpiM", replace;

#delimit cr;